@@ -36,6 +36,7 @@ except ModuleNotFoundError:
 
 import flux
 from flux import debugged, job, util
+from flux.cli.plugin import CLIPluginRegistry
 from flux.constraint.parser import ConstraintParser, ConstraintSyntaxError
 from flux.idset import IDset
 from flux.job import JobspecV1, JobWatcher
@@ -230,6 +231,8 @@ def list_split(opts):
     """
     Return a list by splitting each member of opts on ','
     """
+    if isinstance(opts, str):
+        return list_split([opts])
     if opts:
         x = chain.from_iterable([x.split(",") for x in opts])
         return list(x)
@@ -757,7 +760,11 @@ class MiniCmd:
         self.exitcode = 0
         self.progress = None
         self.watcher = None
+        self.plugins = CLIPluginRegistry(prog)
         self.parser = self.create_parser(prog, usage, description, exclude_io)
+        group = self.parser.add_argument_group("Options provided by plugins")
+        for option in self.plugins.options:
+            group.add_argument(option.name, **option.kwargs)
 
     @staticmethod
     def create_parser(
@@ -1016,6 +1023,9 @@ class MiniCmd:
         """
         Create a jobspec from args and return it to caller
         """
+        # allow plugins to initialize args
+        self.plugins.preinit(args)
+
         jobspec = self.init_jobspec(args)
 
         jobspec.environment, env_expand = get_filtered_environment(args.env)
@@ -1086,6 +1096,9 @@ class MiniCmd:
             for arg in args.add_file:
                 self.handle_add_file_arg(jobspec, arg)
 
+        # allow plugins to modify jobspec after its construction
+        self.plugins.modify_jobspec(args, jobspec)
+
         return jobspec
 
     def submit_async(self, args, jobspec=None):
